Package: surveytable
Title: Streamlining Complex Survey Estimation and Reliability
        Assessment in R
Version: 0.10.0
Authors@R: 
    person(given = "Alex"
        , family = "Strashny"
        , role = c("aut", "cre")
        , email = "alex.strashny@gmail.com"
        , comment = c(ORCID = "0000-0002-6408-7745")
        )
Description: Short and understandable commands that generate tabulated, 
    formatted, and rounded survey estimates. Mostly a wrapper for the 
    'survey' package (Lumley (2004) <doi:10.18637/jss.v009.i08> 
    <https://CRAN.R-project.org/package=survey>) that identifies 
    low-precision estimates using the National Center for Health 
    Statistics (NCHS) presentation standards (Parker et al. (2017) 
    <https://www.cdc.gov/nchs/data/series/sr_02/sr02_175.pdf>,
    Parker et al. (2023) <doi:10.15620/cdc:124368>).
Date/Publication: 2026-08-19 20:10:03 UTC
License: Apache License (>= 2)
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 3.5)
LazyData: true
LazyDataCompression: bzip2
Imports: assertthat, magrittr, glue, survey, huxtable
Suggests: gt, kableExtra, openxlsx2, mschart, flextable, officer,
        dplyr, knitr, rmarkdown
VignetteBuilder: knitr
URL: https://cdcgov.github.io/surveytable/,
        https://github.com/CDCgov/surveytable
Language: en-US
NeedsCompilation: no
Packaged: 2026-08-19 15:08:57 UTC; kpr9
Author: Alex Strashny [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6408-7745>)
Maintainer: Alex Strashny <alex.strashny@gmail.com>
Repository: CRAN
