# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,astra_table)
S3method(print,astra_list)
S3method(print,astra_table)
export(codebook)
export(restructure)
export(set_opts)
export(set_survey)
export(show_options)
export(show_opts)
export(survey_subset)
export(svyciprop_adjusted)
export(tab)
export(tab_cross)
export(tab_rate)
export(tab_subset)
export(tab_subset_rate)
export(total)
export(total_rate)
export(var_all)
export(var_any)
export(var_case)
export(var_collapse)
export(var_copy)
export(var_cross)
export(var_cut)
export(var_list)
export(var_not)
import(assertthat)
import(glue)
import(magrittr)
import(survey)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,confint)
importFrom(stats,p.adjust)
importFrom(stats,pt)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,setNames)
importFrom(utils,capture.output)
importFrom(utils,head)
importFrom(utils,packageVersion)
importFrom(utils,tail)
importFrom(utils,write.table)
